==> applet-service-1.0.2-20190425.052230-26-sources.jar: com/bizvane/appletservice/models/bo/AppletBrandMenberBo.java <==
package com.bizvane.appletservice.models.bo;

public class AppletBrandMenberBo {
    private Long sysBrandId;
    private String memberCode;
    private boolean isOpenCard;
    private String oderMemberCode;
    private String phone;
    private String mktTaskId;
    private String propertyCode;
    private Long sysCompanyId;

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public boolean isOpenCard() {
        return isOpenCard;
    }

    public void setOpenCard(boolean openCard) {
        isOpenCard = openCard;
    }

    public String getOderMemberCode() {
        return oderMemberCode;
    }

    public void setOderMemberCode(String oderMemberCode) {
        this.oderMemberCode = oderMemberCode;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getMktTaskId() {
        return mktTaskId;
    }

    public void setMktTaskId(String mktTaskId) {
        this.mktTaskId = mktTaskId;
    }

    public String getPropertyCode() {
        return propertyCode;
    }

    public void setPropertyCode(String propertyCode) {
        this.propertyCode = propertyCode;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    @Override
    public String toString() {
        return "AppletBrandMenberBo{" +
                "sysBrandId=" + sysBrandId +
                ", memberCode='" + memberCode + '\'' +
                ", isOpenCard=" + isOpenCard +
                ", oderMemberCode='" + oderMemberCode + '\'' +
                ", phone='" + phone + '\'' +
                ", mktTaskId='" + mktTaskId + '\'' +
                ", propertyCode='" + propertyCode + '\'' +
                ", sysCompanyId=" + sysCompanyId +
                '}';
    }
}

==> applet-service-1.0.2-20190708.114742-32-sources.jar: com/bizvane/appletservice/models/bo/AppletBrandMenberBo.java <==
package com.bizvane.appletservice.models.bo;

public class AppletBrandMenberBo {
    private Long sysBrandId;
    private String memberCode;
    private boolean isOpenCard;
    private String oderMemberCode;
    private String phone;
    private String mktTaskId;
    private String propertyCode;
    private Long sysCompanyId;
    private String skipByBrandId;
    private String activityNo;
    private String activityOrdersNo;

    public String getActivityNo() {
		return activityNo;
	}

	public void setActivityNo(String activityNo) {
		this.activityNo = activityNo;
	}

	public String getActivityOrdersNo() {
		return activityOrdersNo;
	}

	public void setActivityOrdersNo(String activityOrdersNo) {
		this.activityOrdersNo = activityOrdersNo;
	}

	public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public boolean isOpenCard() {
        return isOpenCard;
    }

    public void setOpenCard(boolean openCard) {
        isOpenCard = openCard;
    }

    public String getOderMemberCode() {
        return oderMemberCode;
    }

    public void setOderMemberCode(String oderMemberCode) {
        this.oderMemberCode = oderMemberCode;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getMktTaskId() {
        return mktTaskId;
    }

    public void setMktTaskId(String mktTaskId) {
        this.mktTaskId = mktTaskId;
    }

    public String getPropertyCode() {
        return propertyCode;
    }

    public void setPropertyCode(String propertyCode) {
        this.propertyCode = propertyCode;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public String getSkipByBrandId() {
        return skipByBrandId;
    }

    public void setSkipByBrandId(String skipByBrandId) {
        this.skipByBrandId = skipByBrandId;
    }
}
